.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _canary-cmake:

canary_cmake
============

The `canary_cmake <https://github.com/sandialabs/canary/tree/main/src/canary_cmake>`_ plugin extends `canary <https://github.com/sandialabs/canary>`_ to

* add functions and targets to `CMake <https://cmake.org>`_ for generating ``canary`` test and configuration files in your ``CMakeLists.txt``;
* run `CTest <https://cmake.org/cmake/help/latest/manual/ctest.1.html>`_ files generated by CMake natively; and
* generate `CDash <https://www.cdash.org>`_ xml files and post them to your CDash server.

Installation
------------

At this time, ``canary_cmake`` is installed with ``canary``::

   pip install canary-wm

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   CMake<cmake>
   CTest<ctest>
   CDash<cdash>
